- Überblick
- Anforderungen
- Vor der Installation
- Vorbereiten der Installation
- Herunterladen der Installationspakete
- Konfigurieren der OCI-konformen Registrierung
- Gewährung von Installationsberechtigungen mit Clusterrollen
- Gewährung von Installationsberechtigungen ohne Clusterrollen
- Installieren und Konfigurieren des Dienstgeflechts
- Installieren und Konfigurieren des GitOps-Tools
- Installieren des Operators für externe Geheimnisse
- Bereitstellen von Redis über OperatorHub
- Anwenden verschiedener Konfigurationen
- Ausführen von uipathctl
- Installation
- Nach der Installation
- Migration und Upgrade
- Überwachung und Warnungen
- Clusterverwaltung
- Produktspezifische Konfiguration
- Erweiterte Orchestrator-Konfiguration
- Konfigurieren von Orchestrator-Parametern
- Konfigurieren von AppSettings
- Konfigurieren der maximalen Anforderungsgröße
- Überschreiben der Speicherkonfiguration auf Clusterebene
- Konfigurieren von NLog
- Speichern von Roboterprotokollen in Elasticsearch
- Konfigurieren von Anmeldeinformationsspeichern
- Konfigurieren der Verwendung von einem Verschlüsselungsschlüssel pro Mandant
- Bereinigen der Orchestrator-Datenbank
- Installation der Hostbibliothek überspringen
- AI Trust Layer
- Fehlersuche und ‑behebung
- Deinstallieren der Automation Suite
- So beheben Sie einen Fehler bei der Überprüfung der Prereq-Konnektivität unter OpenShift 4.16–4.18
- So stellen Sie Insights in einem FIPS-fähigen Cluster bereit
- So deaktivieren Sie die automatische CDI-Aktivierung im Nvidia GPU-Operator
- So codieren Sie ein PostgreSQL-Verbindungszeichenfolgenkennwort für eine URL
- 500 Fehler und Ratenbegrenzung für S3-Anforderungen in ODF
- Fehlerbehebung bei externen Geheimnissen
- Konfigurieren von CSI-Treibertoleranzen für ODF 4.20
- Temporär als Dienst-Fehlerbehebung
- AI Center und Document Understanding Pods können bei aktivierter TLS-Zertifikatsverifizierung nicht gestartet werden
- Studio Desktop kann keine Integration Service-Connectors und -Aktivitäten laden
- Validierungsfehler beim TLS-Zertifikat
- Manuelle Schadensbegrenzung bei ArgoCD NetworkPolicy (GHSA-47m3-95c7-g2g8)
- Konfigurieren von Ressourcenanforderungen und Limits für von uipathctl erstellte Workloads
Überschreiben der Speicherkonfiguration auf Clusterebene
Überschreiben Sie die Speicherkonfiguration auf Clusterebene auf Produktebene in der Automation Suite auf OpenShift.
Der Orchestrator unterstützt die folgenden Speicherkonfigurationen:
- Speicherkonfiguration auf Clusterebene
- Speicherkonfiguration auf Orchestrator-Ebene
Es wird empfohlen, die Konfiguration auf Clusterebene in Verbindung mit einem externen Speicher zu verwenden. Dadurch kann der Orchestrator die Einstellungen automatisch erkennen und verwenden, sodass zusätzliche Konfigurationen nicht erforderlich sind.
Konfigurieren von Azure-/Amazon S3-Speicher-Buckets
Um den Speicheranbieter auf Orchestrator-Ebene zu konfigurieren, aktualisieren Sie die Orchestrator-Parameter, indem Sie die folgenden Schritte ausführen. Weitere Informationen finden Sie unter Konfigurieren von Orchestrator-Parametern.
- Fügen Sie in der Konfigurationsdatei unter
orchestratorden Abschnittlegacy_storage_providerhinzu, der den Speichertyp und die Verbindungszeichenfolge enthält, wie im folgenden Beispiel gezeigt:"orchestrator": { "enabled": true, "legacy_object_storage": { "type": "Azure", "connection_string": "DefaultEndpointsProtocol=https;AccountName=usr;AccountKey=...;EndpointSuffix=core.windows.net" } }"orchestrator": { "enabled": true, "legacy_object_storage": { "type": "Azure", "connection_string": "DefaultEndpointsProtocol=https;AccountName=usr;AccountKey=...;EndpointSuffix=core.windows.net" } } - Stellen Sie den gewünschten Anbieter mit dem Parameter
typeein. Mögliche Werte sind:Azure,AWSundMinio. Einige Überlegungen:- Bei den
storage.type-Parameterwerten wird die Groß-/Kleinschreibung beachtet. FileSystem-Speicherkonfiguration wird nicht unterstützt.
- Bei den
- Fügen Sie die Verbindungszeichenfolge für den Speicheranbieter mit dem Parameter
connection_stringhinzu. Weitere Informationen zum Format der Verbindungszeichenfolgen finden Sie im AbschnittStorage.Locationvon UiPath.Orchestrator.dll.config.
Der Orchestrator-Webbrowserzugriff auf Amazon- und Azure Storage-Buckets kann aufgrund von Richtlinien zur gleichen Quelle auf der Anbieterseite eingeschränkt sein. Um erfolgreich auf den Inhalt eines solchen Buckets zuzugreifen, müssen Sie den jeweiligen Anbieter so konfigurieren, dass Anforderungen zwischen verschiedenen Quellen vom Orchestrator zugelassen werden. Anweisungen finden Sie unter CORS/CSP-Konfiguration.
Hochladen von Dateien in den Speicher
Dateien können mit dem uipathctl -Befehlszeilentool in den Speicher hochgeladen werden. Verwenden Sie dazu den folgenden Befehl:
uipathctl config orchestrator upload [parameters]
uipathctl config orchestrator upload [parameters]
| Parameter | Beschreibung |
|---|---|
--storage-directory <string> | Ort des Speicherverzeichnisses auf dem lokalen Datenträger. |
--nlog-extensions-directory <string> | Speicherort der NLog-Erweiterungen auf dem lokalen Datenträger. |
--securestore-plugins-directory <string> | Speicherort der Secure Store-Plugins auf dem lokalen Datenträger. |
--is-external-storage | Gibt an, ob der Speicher extern ist oder nicht. |
--namespace <string> | Der Namespace, in dem die Automation Suite bereitgestellt wird. Der Standardwert ist uipath. |
-h, --help | Stellt Hilfe für den Upload-Befehl bereit. |
Wenn Sie eine externe Speicherkonfiguration auf Clusterebene verwenden, müssen Sie dies angeben, indem Sie den Parameter --is-external-storage bei der Verwendung des Befehls einschließen.
Überlegungen zum Speicherupload
Das mit dem Parameter --storage-directory angegebene Verzeichnis muss mindestens ein Unterverzeichnis enthalten. Alle Unterverzeichnisse werden in den Speicher kopiert.
Dateien, die mit --storage-directory in den Stammordner hochgeladen werden, werden ignoriert.
Interner Speicher
Unterverzeichnisse werden direkt in das Bucket kopiert, wobei der Name des Unterverzeichnisses als Pfad verwendet wird.
Externer Speicher
- Wenn das Unterverzeichnis
orchestrator-hostheißt, wird sein Inhalt in den PfadOrchestrator-Hostkopiert. - Wenn das Unterverzeichnis
orchestrator-<name>heißt, wird sein Inhalt in den PfadO<name>kopiert. - In allen anderen Fällen wird der Inhalt des Unterverzeichnisses in den Pfad
<name>kopiert.
Anwendungsbeispiele
-
Hochladen von Dateien in den Speicher:
uipathctl config orchestrator upload --storage-directory /path/to/storage/directoryuipathctl config orchestrator upload --storage-directory /path/to/storage/directory -
Hochladen von NLog-Erweiterungen in den Speicher:
uipathctl config orchestrator upload --nlog-extensions-directory /path/to/nlog/extensions/directoryuipathctl config orchestrator upload --nlog-extensions-directory /path/to/nlog/extensions/directory -
Hochladen von sicheren Speicher-Plugins in den Speicher:
uipathctl config orchestrator upload --securestore-plugins-directory /path/to/securestore/plugins/directoryuipathctl config orchestrator upload --securestore-plugins-directory /path/to/securestore/plugins/directory -
Hochladen von Dateien in einen externen Speicher:
uipathctl config orchestrator upload --is-external-storage --storage-directory /path/to/storage/directoryuipathctl config orchestrator upload --is-external-storage --storage-directory /path/to/storage/directory -
Hochladen von NLog-Erweiterungen in den externen Speicher:
uipathctl config orchestrator upload --is-external-storage --nlog-extensions-directory /path/to/nlog/extensions/directoryuipathctl config orchestrator upload --is-external-storage --nlog-extensions-directory /path/to/nlog/extensions/directory -
Hochladen von sicheren Speicher-Plugins in einen externen Speicher:
uipathctl config orchestrator upload --is-external-storage --securestore-plugins-directory /path/to/securestore/plugins/directoryuipathctl config orchestrator upload --is-external-storage --securestore-plugins-directory /path/to/securestore/plugins/directory